==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/start.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	start.lang.inc.php 2018-09-10
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ALL_LAST_VISITORS' => 'Alle Besucher:',
	'ARTICLE_SOLD' => 'Verkaufte Artikel',
	'ATTENTION_TITLE' => '! ACHTUNG !',
	'DAILY_AVERAGE' => 'Täglicher Durchschnitt:',
	'DATE_TIME' => 'Datum / Uhrzeit:',
	'DAY_SUMMARY' => '30 Tage Übersicht:',
	'ENTRY_PAGE' => 'Einstiegsseite:',
	'FIRST_VISIT_ON' => 'Erster Besuch:',
	'HEADING_QUICK_STATS' => 'Kurzübersicht',
	'HEADING_TITLE' => 'Willkommen',
	'HEADING_DASHBOARD' => 'Dashboard',
	'HITS' => 'Hits',
	'HOST' => 'Host',
	'HOURLY_TRAFFIC_SUMMARY' => 'Stündliche Traffic Zusammenfassung',
	'IP_ADRESS' => 'IP Adresse:',
	'LAST_ORDERS' => 'Letzte Bestellungen',
	'LAST_VISITORS' => 'Letzte 100 Besucher:',
	'LIST_ALL' => 'Alle anzeigen',
	'MENU_TITLE_TO' => 'bis',
	'OPERATING_SYSTEM' => 'Betriebssystem:',
	'OPERATING_SYSTEM_SUMMARY' => 'Betriebssystem Übersicht',
	'PERCENTAGE' => 'Prozentanteil',
	'REFERRING_URL' => 'Refferrer Url',
	'REFFERING_HOST' => 'Referring Host:',
	'REPORT_GENERATED_FOR' => 'Report für:',
	'REPORT_GENERATED_ON' => 'Erstellt am:',
	'SEARCHTERM_EXTERN' => 'Suchbegriffe extern',
	'SEARCHTERM_INTERN' => 'Suchbegriffe intern',
	'SEARCH_ENGINE_SUMMARY' => 'Suchmaschinen Übersicht',
	'SEARCH_ENGINE_SUMMARY_TEXT' => ' ( Prozentangaben basieren auf die Gesamtzahl der Besuche über Suchmaschinen. )',
	'SEARCH_QUERY_SUMMARY' => 'Suchanfragen Übersicht',
	'SEARCH_QUERY_SUMMARY_TEXT' => ' ) ( Prozentangaben basieren auf die Gesamtzahl der Suchanfragen die geloggt wurden. )',
	'SELECT_TIMESPAN' => 'Zeitraum:',
	'SELECT_ITEM' => 'Chart:',
	'SHOW_TAB' => 'Zeige:',
	'STATISTICS' => 'Statistiken',
	'STATISTICS_AVERGAGE_ORDER_VALUE' => 'Ø Bestellwert',
	'STATISTICS_CONVERSION_RATE' => 'Conversion Rate',
	'STATISTICS_NEW_CUSTOMERS' => 'Neue Kunden',
	'STATISTICS_ORDERS_COUNT' => 'Bestellungen',
	'STATISTICS_SALES' => 'Umsatz',
	'STATISTICS_USERS_ONLINE' => 'Besucher online',
	'STATISTICS_VISITORS' => 'Besucher',
	'STATISTICS_INTERVAL_TODAY' => 'Heute',
	'STATISTICS_INTERVAL_ONE_WEEK' => '1 Woche',
	'STATISTICS_INTERVAL_TWO_WEEKS' => '2 Wochen',
	'STATISTICS_INTERVAL_ONE_MONTH' => '1 Monat',
	'STATISTICS_INTERVAL_THREE_MONTHS' => '3 Monate',
	'STATISTICS_INTERVAL_SIX_MONTHS' => '6 Monate',
	'STATISTICS_INTERVAL_ONE_YEAR' => '1 Jahr',
	'TEXT_DB_UPDATE_WARNING' => 'Das <a href="%sgm_updater.php"><u>Datenbankupdate</u></a> zu Ihrer Shopversion wurde noch nicht ausgeführt. Bitte führen Sie dies gemäß der Installationsanleitung durch.',
	'TEXT_FILE_WARNING' => '<b>Warnung:</b><br>Folgende Dateien sind vom Server beschreibbar. Bitte ändern Sie die Zugriffsrechte (Permissions) dieser Datei aus Sicherheitsgründen. <b>(444)</b> in unix, <b>(read-only)</b> in Win32.',
	'TEXT_FOLDER_WARNING' => 'Folgende Verzeichnisse müssen vom Server beschreibbar sein. Bitte ändern Sie die Zugriffsrechte (Permissions) dieser Verzeichnisse. <b>(777)</b> in unix, <b>(read-write)</b> in Win32.',
	'TEXT_HTACCESS_VERSION_WARNING' => '<b>Warnung:</b><br>Ihre .htaccess-Datei im Hauptverzeichnis des Shops ist veraltet und entspricht nicht der aktuellen Version.<br />Wenn Sie keine eigenen Anpassungen in der Datei vorgenommen haben, kopieren Sie einfach die Vorlage aus gm/seo_boost_an/.htaccess in das Hauptverzeichnis Ihres Shops, andernfalls gleichen Sie Ihre Anpassungen mit der dortigen Vorlage ab.',
	'TEXT_MEMORY_LIMIT_WARNING' => '<n>Warnung:</b><br>In der Serverkonfiguration ist für das "memory_limit" ein zu niedriger Wert gesetzt, um alle Funktionen des Shops nutzen zu können. Wir empfehlen als Wert mindestens %sM.<br />Wenden Sie sich an Ihren Provider mit der Bitte das "memory_limit" entsprechend zu erhöhen.',
	'TEXT_NEWS_LOADING' => 'News werden geladen.',
	'TEXT_OBSOLETE_WARNING' => 'Folgende Dateien sind veraltet und müssen aktualisiert werden.',
	'TEXT_REGISTER_GLOBAL' => 'Php-Einstellung: <b>register_globals</b> ist an! <br /> Diese Funktion kann zu verschiedenen Problemen im Shop führen.<br /> Bitte deaktivieren Sie <b>register_globals</b> in den php-Einstellungen oder kontaktieren Sie ihren Hosting-Provider, um dies vornehmen zu lassen.',
	'TEXT_LAST_RUN' => 'Letzte Überprüfung: ',
	'TITLE_IMPRESSIONS' => 'Seitenaufrufe',
	'TITLE_NEWS' => 'Gambio News',
	'TITLE_ORDERS' => 'Bestellungen',
	'TITLE_OVERVIEW' => 'Übersicht',
	'TITLE_RATE' => 'Veränderung',
	'TITLE_SALES' => 'Umsätze',
	'TITLE_TODAY' => 'Heute',
	'TITLE_TOP_LIST' => 'Top-List',
	'TITLE_VISITOR' => 'Besucher',
	'TITLE_VISITORS' => 'Besucher gestern und heute',
	'TITLE_Y' => 'Besucher',
	'TITLE_YESTERDAY' => 'Gestern',
	'TODAY_VISITORS' => 'Besucher von heute:',
	'TOP_ENGINE' => 'Top Suchmaschine:',
	'TOP_HOSTS' => 'Top Ten Hosts',
	'TOP_REFERRERS' => 'Top 10 Referrer',
	'TOP_REFFERER' => 'Top Refferer:',
	'TOTAL_UNIQUE' => 'Einzelbesucher insgesammt:',
	'TOTAL_VISITS' => 'Besuche insgesammt:',
	'UNIQUE_TODAY' => 'Einzelne Besucher:',
	'VERY_LAST_VISITORS' => 'Letzte 10 Besucher:',
	'VISITS_TODAY' => 'Besuche heute:',
	'WEB_BROWSER_SUMMARY' => 'Web Browser Übersicht'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/start.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	start.lang.inc.php 2018-09-10
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ALL_LAST_VISITORS' => 'Alle Besucher:',
	'ARTICLE_SOLD' => 'Verkaufte Artikel',
	'ATTENTION_TITLE' => '! ACHTUNG !',
	'DAILY_AVERAGE' => 'Täglicher Durchschnitt:',
	'DATE_TIME' => 'Datum / Uhrzeit:',
	'DAY_SUMMARY' => '30 Tage Übersicht:',
	'ENTRY_PAGE' => 'Einstiegsseite:',
	'FIRST_VISIT_ON' => 'Erster Besuch:',
	'HEADING_QUICK_STATS' => 'Kurzübersicht',
	'HEADING_TITLE' => 'Willkommen',
	'HEADING_DASHBOARD' => 'Dashboard',
	'HITS' => 'Hits',
	'HOST' => 'Host',
	'HOURLY_TRAFFIC_SUMMARY' => 'Zusammenfassung des stündlichen Traffics',
	'IP_ADRESS' => 'IP Adresse:',
	'LAST_ORDERS' => 'Letzte Bestellungen',
	'LAST_VISITORS' => 'Letzte 100 Besucher:',
	'LIST_ALL' => 'Alle anzeigen',
	'MENU_TITLE_TO' => 'bis',
	'OPERATING_SYSTEM' => 'Betriebssystem:',
	'OPERATING_SYSTEM_SUMMARY' => 'Betriebssystem Übersicht',
	'PERCENTAGE' => 'Prozentanteil',
	'REFERRING_URL' => 'Refferrer Url',
	'REFFERING_HOST' => 'Referring Host:',
	'REPORT_GENERATED_FOR' => 'Report für:',
	'REPORT_GENERATED_ON' => 'Erstellt am:',
	'SEARCHTERM_EXTERN' => 'Suchbegriffe extern',
	'SEARCHTERM_INTERN' => 'Suchbegriffe intern',
	'SEARCH_ENGINE_SUMMARY' => 'Suchmaschinen Übersicht',
	'SEARCH_ENGINE_SUMMARY_TEXT' => ' (Prozentangaben basieren auf der Gesamtzahl der Besuche über Suchmaschinen.)',
	'SEARCH_QUERY_SUMMARY' => 'Suchanfragen Übersicht',
	'SEARCH_QUERY_SUMMARY_TEXT' => ' ) (Prozentangaben basieren auf der Gesamtzahl der Suchanfragen, die geloggt wurden.)',
	'SELECT_TIMESPAN' => 'Zeitraum:',
	'SELECT_ITEM' => 'Chart:',
	'SHOW_TAB' => 'Zeige:',
	'STATISTICS' => 'Statistiken',
	'STATISTICS_AVERGAGE_ORDER_VALUE' => 'Ø Bestellwert',
	'STATISTICS_CONVERSION_RATE' => 'Conversion Rate',
	'STATISTICS_NEW_CUSTOMERS' => 'Neue Kunden',
	'STATISTICS_ORDERS_COUNT' => 'Bestellungen',
	'STATISTICS_SALES' => 'Umsatz',
	'STATISTICS_USERS_ONLINE' => 'Besucher online',
	'STATISTICS_VISITORS' => 'Besucher',
	'STATISTICS_INTERVAL_TODAY' => 'Heute',
	'STATISTICS_INTERVAL_ONE_WEEK' => '1 Woche',
	'STATISTICS_INTERVAL_TWO_WEEKS' => '2 Wochen',
	'STATISTICS_INTERVAL_ONE_MONTH' => '1 Monat',
	'STATISTICS_INTERVAL_THREE_MONTHS' => '3 Monate',
	'STATISTICS_INTERVAL_SIX_MONTHS' => '6 Monate',
	'STATISTICS_INTERVAL_ONE_YEAR' => '1 Jahr',
	'TEXT_DB_UPDATE_WARNING' => 'Das <a href="%sgm_updater.php"><u>Datenbankupdate</u></a> zu deiner Shopversion wurde noch nicht ausgeführt. Bitte führe dies gemäß der Installationsanleitung durch.',
	'TEXT_FILE_WARNING' => '<b>Warnung:</b><br>Folgende Dateien sind vom Server beschreibbar. Bitte ändere die Zugriffsrechte (Permissions) dieser Datei aus Sicherheitsgründen. <b>(444)</b> in unix, <b>(read-only)</b> in Win32.',
	'TEXT_FOLDER_WARNING' => 'Folgende Verzeichnisse müssen vom Server beschreibbar sein. Bitte ändere die Zugriffsrechte (Permissions) dieser Verzeichnisse. <b>(777)</b> in unix, <b>(read-write)</b> in Win32.',
	'TEXT_HTACCESS_VERSION_WARNING' => '<b>Warnung:</b><br>Deine .htaccess-Datei im Hauptverzeichnis des Shops ist veraltet und entspricht nicht der aktuellen Version.<br />Wenn du keine eigenen Anpassungen in der Datei vorgenommen hast, kopiere einfach die Vorlage aus gm/seo_boost_an/.htaccess in das Hauptverzeichnis deines Shops, andernfalls gleiche deine Anpassungen mit der dortigen Vorlage ab.',
	'TEXT_MEMORY_LIMIT_WARNING' => '<n>Warnung:</b><br>In der Serverkonfiguration ist für das "memory_limit" ein zu niedriger Wert gesetzt, um alle Funktionen des Shops nutzen zu können. Wir empfehlen, als Wert mindestens %sM.<br />Wende dich an deinen Provider mit der Bitte, das "memory_limit" entsprechend zu erhöhen.',
	'TEXT_NEWS_LOADING' => 'News werden geladen.',
	'TEXT_OBSOLETE_WARNING' => 'Folgende Dateien sind veraltet und müssen aktualisiert werden.',
	'TEXT_REGISTER_GLOBAL' => 'Php-Einstellung: <b>register_globals</b> ist an! <br /> Diese Funktion kann zu verschiedenen Problemen im Shop führen.<br /> Bitte deaktiviere <b>register_globals</b> in den php-Einstellungen oder kontaktiere deinen Hosting-Provider, um dies vornehmen zu lassen.',
	'TEXT_LAST_RUN' => 'Letzte Überprüfung: ',
	'TITLE_IMPRESSIONS' => 'Seitenaufrufe',
	'TITLE_NEWS' => 'Gambio News',
	'TITLE_ORDERS' => 'Bestellungen',
	'TITLE_OVERVIEW' => 'Übersicht',
	'TITLE_RATE' => 'Veränderung',
	'TITLE_SALES' => 'Umsätze',
	'TITLE_TODAY' => 'Heute',
	'TITLE_TOP_LIST' => 'Top-List',
	'TITLE_VISITOR' => 'Besucher',
	'TITLE_VISITORS' => 'Besucher gestern und heute',
	'TITLE_Y' => 'Besucher',
	'TITLE_YESTERDAY' => 'Gestern',
	'TODAY_VISITORS' => 'Besucher von heute:',
	'TOP_ENGINE' => 'Top Suchmaschine:',
	'TOP_HOSTS' => 'Top Ten Hosts',
	'TOP_REFERRERS' => 'Top 10 Referrer',
	'TOP_REFFERER' => 'Top Refferer:',
	'TOTAL_UNIQUE' => 'Einzelbesucher insgesammt:',
	'TOTAL_VISITS' => 'Besuche insgesammt:',
	'UNIQUE_TODAY' => 'Einzelne Besucher:',
	'VERY_LAST_VISITORS' => 'Letzte 10 Besucher:',
	'VISITS_TODAY' => 'Besuche heute:',
	'WEB_BROWSER_SUMMARY' => 'Web Browser Übersicht'
);
